@@ -52,6 +52,8 @@ class Project(BaseProject, flow.InjectionProvider):
             return Sequence
         elif slot_name == 'libreflow.baseflow.shot.Shot':
             return Shot
+        elif slot_name == 'libreflow.baseflow.task.ManagedTask':
+            return Task
         elif slot_name == 'libreflow.baseflow.users.User':
             return User
         elif slot_name == 'libreflow.baseflow.ProjectSettings':
