@@ -1,11 +1,11 @@
 from kabaret import flow
 from libreflow.baseflow.shot import ShotCollection, Shot as BaseShot, Sequence as BaseSequence
-from libreflow.baseflow.task import TaskCollection
+from libreflow.baseflow.task import ManagedTaskCollection
 
 
 class Shot(BaseShot):
     
-    tasks = flow.Child(TaskCollection).ui(
+    tasks = flow.Child(ManagedTaskCollection).ui(
         expanded=True,
         show_filter=True
     )
